@@ -55,4 +55,16 @@ def touch(file, mt=None):
     p = piped(params)
     p.communicate()
 
-    return p.returncode == 0
\ No newline at end of file
+    return p.returncode == 0
+
+def pngquant(src, quality=None):
+    params = ['pngquant', '--force', '--ext', '.png']
+
+    if quality:
+        params.append('-q')
+        params.append(str(quality))
+
+    params.append(src)
+
+    p = piped(params)
+    o, e = p.communicate()
\ No newline at end of file
